
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.004003
eval "use Test::Spelling 0.12; use Pod::Wordlist::hanekomu; 1" or die $@;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Datasets
JS
Javascript
RGB
TODO
dataset
datasets
distro
embeddable
hlc
opacity
px
subclass's
DROLSKY
DROLSKY's
Rolsky
Rolsky's
Dave
autarch
lib
Chart
OFC
Dataset
Scatter
Types
YAxis
Line
XAxis
3DBar
Axis
GlassBar
FadeBar
Role
OFCDataLines
HighLowClose
AxisLabel
Pie
Candle
OutlinedBar
Area
Grid
SketchBar
LineWithDots
Bar
